<?php

namespace Teknisa\EST\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;


class Est33000RequisicaoEstoqueController extends \Teknisa\EST\Controllers\TeknisaCrud {
	protected $dataSourceName = '';
	protected $parameterBagColumns = array('');
    protected $est33000requisicaoestoqueservice;

    public function __construct($crudService, $parameterBag,$est33000requisicaoestoqueservice) {
        parent::__construct($crudService, $parameterBag);
        $this->est33000requisicaoestoqueservice = $est33000requisicaoestoqueservice;
    }

	public function findRequisicaoEstoque(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $this->dataSourceName = 'requesto_completa' ;
            $this->parameterBagColumns =  array("CDLOCALORIG","CDSETOR","CDLOCALDEST","P_DTPREVFIN","P_TCDSETOR","P_DTREQUINI","P_DTREQUFIN","CDALMOXDEST","CDFILIAL","P_DTPREVINI","CDALMOXORIG","IDSTATUSREQ");
            parent::find($request,$response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function findItemRequisicaoEstoque(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $this->dataSourceName = 'itrequesto_produto_itlanctoest' ;
            $this->parameterBagColumns =  array("P_CDFILIAL","P_NRREQUESTO");
            parent::find($request,$response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function findLote(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $this->dataSourceName = 'lote_marca_posestatu' ;
            $this->parameterBagColumns =  array("P_CDFILIAL","P_NRLOTEESTQ","P_CDPRODUTO");
            parent::find($request,$response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function saveRequisicao(DTO\Request $request, DTO\Response $response) {
        try {
            $this->dataSourceName = 'requesto';
            parent::save($request,$response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function updateProduto(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getDataSet()->getRows()[0];
	        $this->dataSourceName = 'itrequesto_produto_itlanctoest' ;
            if($row["__is_new"]){
                parent::save($request,$response);
            } else {
                $this->est33000requisicaoestoqueservice->updateProduto($row);
            }
            
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function saveNovaRequisicao(DTO\Request $request, DTO\Response $response) {
        try {
            $requisicao = $request->getRow()['requisicao'];
            $produtos = $request->getRow()['produtos'];

            $arrayRequisicao[] = $requisicao;
            $dataSetRequisicao = new DataSet('requesto_completa', $arrayRequisicao);
            $requestRequisicao = new DTO\Request\DataSet($dataSetRequisicao, $request->getMethod(),$request->getRoutePath(), $request->getUserId());
            $rowRequsicao = $this->crudService->getRowsToSave($requestRequisicao,'requesto');
            $arrayProdutos[] = $produtos;
            $dataSetProdutos = new DataSet('itrequesto_produto_itlanctoest', $arrayProdutos);
            $requestProdutos = new DTO\Request\DataSet($dataSetProdutos, $request->getMethod(),$request->getRoutePath(), $request->getUserId());
            $rowProdutos = $this->crudService->getRowsToSave($requestProdutos,'itrequesto');
            
            $dataSet = $this->est33000requisicaoestoqueservice->salvarNovaRequisicao($rowRequsicao,$rowProdutos);
            $response->addDataSet($dataSet);

        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function saveNovoProduto(DTO\Request $request, DTO\Response $response) {
        try {
            $rowProduto = $this->crudService->getRowsToSave($request,'itrequesto');
            $dataSet = $this->est33000requisicaoestoqueservice->salvarNovoProduto($rowProduto[0]);
            $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function deleteProduto(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $dataSet = $this->est33000requisicaoestoqueservice->deletarProduto($row);
            $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function deleteRequisicao(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $this->est33000requisicaoestoqueservice->deletarRequisicao($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }


}